@@ -15,29 +15,29 @@ Usage::
 from datetime import datetime
 from typing import Any, Dict, List, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import PermissionsModeType
 from .type_defs import (
-    CancelJournalKinesisStreamResponseResponseTypeDef,
-    CreateLedgerResponseResponseTypeDef,
-    DescribeJournalKinesisStreamResponseResponseTypeDef,
-    DescribeJournalS3ExportResponseResponseTypeDef,
-    DescribeLedgerResponseResponseTypeDef,
-    ExportJournalToS3ResponseResponseTypeDef,
-    GetBlockResponseResponseTypeDef,
-    GetDigestResponseResponseTypeDef,
-    GetRevisionResponseResponseTypeDef,
+    CancelJournalKinesisStreamResponseTypeDef,
+    CreateLedgerResponseTypeDef,
+    DescribeJournalKinesisStreamResponseTypeDef,
+    DescribeJournalS3ExportResponseTypeDef,
+    DescribeLedgerResponseTypeDef,
+    ExportJournalToS3ResponseTypeDef,
+    GetBlockResponseTypeDef,
+    GetDigestResponseTypeDef,
+    GetRevisionResponseTypeDef,
     KinesisConfigurationTypeDef,
-    ListJournalKinesisStreamsForLedgerResponseResponseTypeDef,
-    ListJournalS3ExportsForLedgerResponseResponseTypeDef,
-    ListJournalS3ExportsResponseResponseTypeDef,
-    ListLedgersResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
+    ListJournalKinesisStreamsForLedgerResponseTypeDef,
+    ListJournalS3ExportsForLedgerResponseTypeDef,
+    ListJournalS3ExportsResponseTypeDef,
+    ListLedgersResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     S3ExportConfigurationTypeDef,
-    StreamJournalToKinesisResponseResponseTypeDef,
-    UpdateLedgerPermissionsModeResponseResponseTypeDef,
-    UpdateLedgerResponseResponseTypeDef,
+    StreamJournalToKinesisResponseTypeDef,
+    UpdateLedgerPermissionsModeResponseTypeDef,
+    UpdateLedgerResponseTypeDef,
     ValueHolderTypeDef,
 )
 
@@ -62,30 +62,35 @@ class Exceptions:
     ResourcePreconditionNotMetException: Type[BotocoreClientError]
 
 
-class QLDBClient:
+class QLDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        QLDBClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#can_paginate)
         """
 
     def cancel_journal_kinesis_stream(
         self, *, LedgerName: str, StreamId: str
-    ) -> CancelJournalKinesisStreamResponseResponseTypeDef:
+    ) -> CancelJournalKinesisStreamResponseTypeDef:
         """
         Ends a given Amazon QLDB journal stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#cancel_journal_kinesis_stream)
         """
 
@@ -96,11 +101,11 @@ class QLDBClient:
         PermissionsMode: PermissionsModeType,
         Tags: Dict[str, str] = None,
         DeletionProtection: bool = None
-    ) -> CreateLedgerResponseResponseTypeDef:
+    ) -> CreateLedgerResponseTypeDef:
         """
         Creates a new ledger in your AWS account in the current Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.create_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.create_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#create_ledger)
         """
 
@@ -108,37 +113,37 @@ class QLDBClient:
         """
         Deletes a ledger and all of its contents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.delete_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.delete_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#delete_ledger)
         """
 
     def describe_journal_kinesis_stream(
         self, *, LedgerName: str, StreamId: str
-    ) -> DescribeJournalKinesisStreamResponseResponseTypeDef:
+    ) -> DescribeJournalKinesisStreamResponseTypeDef:
         """
         Returns detailed information about a given Amazon QLDB journal stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_journal_kinesis_stream)
         """
 
     def describe_journal_s3_export(
         self, *, Name: str, ExportId: str
-    ) -> DescribeJournalS3ExportResponseResponseTypeDef:
+    ) -> DescribeJournalS3ExportResponseTypeDef:
         """
         Returns information about a journal export job, including the ledger name,
         export ID, creation time, current status, and the parameters of the original
         export creation request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_journal_s3_export)
         """
 
-    def describe_ledger(self, *, Name: str) -> DescribeLedgerResponseResponseTypeDef:
+    def describe_ledger(self, *, Name: str) -> DescribeLedgerResponseTypeDef:
         """
         Returns information about a ledger, including its state and when it was created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.describe_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.describe_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_ledger)
         """
 
@@ -150,12 +155,12 @@ class QLDBClient:
         ExclusiveEndTime: Union[datetime, str],
         S3ExportConfiguration: "S3ExportConfigurationTypeDef",
         RoleArn: str
-    ) -> ExportJournalToS3ResponseResponseTypeDef:
+    ) -> ExportJournalToS3ResponseTypeDef:
         """
         Exports journal contents within a date and time range from a ledger into a
         specified Amazon Simple Storage Service (Amazon S3) bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#export_journal_to_s3)
         """
 
@@ -169,7 +174,7 @@ class QLDBClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#generate_presigned_url)
         """
 
@@ -179,19 +184,19 @@ class QLDBClient:
         Name: str,
         BlockAddress: "ValueHolderTypeDef",
         DigestTipAddress: "ValueHolderTypeDef" = None
-    ) -> GetBlockResponseResponseTypeDef:
+    ) -> GetBlockResponseTypeDef:
         """
         Returns a block object at a specified address in a journal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.get_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.get_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_block)
         """
 
-    def get_digest(self, *, Name: str) -> GetDigestResponseResponseTypeDef:
+    def get_digest(self, *, Name: str) -> GetDigestResponseTypeDef:
         """
         Returns the digest of a ledger at the latest committed block in the journal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.get_digest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.get_digest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_digest)
         """
 
@@ -202,64 +207,62 @@ class QLDBClient:
         BlockAddress: "ValueHolderTypeDef",
         DocumentId: str,
         DigestTipAddress: "ValueHolderTypeDef" = None
-    ) -> GetRevisionResponseResponseTypeDef:
+    ) -> GetRevisionResponseTypeDef:
         """
         Returns a revision data object for a specified document ID and block address.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.get_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.get_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_revision)
         """
 
     def list_journal_kinesis_streams_for_ledger(
         self, *, LedgerName: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListJournalKinesisStreamsForLedgerResponseResponseTypeDef:
+    ) -> ListJournalKinesisStreamsForLedgerResponseTypeDef:
         """
         Returns an array of all Amazon QLDB journal stream descriptors for a given
         ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_kinesis_streams_for_ledger)
         """
 
     def list_journal_s3_exports(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListJournalS3ExportsResponseResponseTypeDef:
+    ) -> ListJournalS3ExportsResponseTypeDef:
         """
         Returns an array of journal export job descriptions for all ledgers that are
         associated with the current AWS account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_s3_exports)
         """
 
     def list_journal_s3_exports_for_ledger(
         self, *, Name: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListJournalS3ExportsForLedgerResponseResponseTypeDef:
+    ) -> ListJournalS3ExportsForLedgerResponseTypeDef:
         """
         Returns an array of journal export job descriptions for a specified ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_s3_exports_for_ledger)
         """
 
     def list_ledgers(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListLedgersResponseResponseTypeDef:
+    ) -> ListLedgersResponseTypeDef:
         """
         Returns an array of ledger summaries that are associated with the current AWS
         account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.list_ledgers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.list_ledgers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_ledgers)
         """
 
-    def list_tags_for_resource(
-        self, *, ResourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Returns all tags for a specified Amazon QLDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_tags_for_resource)
         """
 
@@ -273,11 +276,11 @@ class QLDBClient:
         StreamName: str,
         Tags: Dict[str, str] = None,
         ExclusiveEndTime: Union[datetime, str] = None
-    ) -> StreamJournalToKinesisResponseResponseTypeDef:
+    ) -> StreamJournalToKinesisResponseTypeDef:
         """
         Creates a journal stream for a given Amazon QLDB ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#stream_journal_to_kinesis)
         """
 
@@ -285,7 +288,7 @@ class QLDBClient:
         """
         Adds one or more tags to a specified Amazon QLDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#tag_resource)
         """
 
@@ -293,26 +296,26 @@ class QLDBClient:
         """
         Removes one or more tags from a specified Amazon QLDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#untag_resource)
         """
 
     def update_ledger(
         self, *, Name: str, DeletionProtection: bool = None
-    ) -> UpdateLedgerResponseResponseTypeDef:
+    ) -> UpdateLedgerResponseTypeDef:
         """
         Updates properties on a ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.update_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.update_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#update_ledger)
         """
 
     def update_ledger_permissions_mode(
         self, *, Name: str, PermissionsMode: PermissionsModeType
-    ) -> UpdateLedgerPermissionsModeResponseResponseTypeDef:
+    ) -> UpdateLedgerPermissionsModeResponseTypeDef:
         """
         Updates the permissions mode of a ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/qldb.html#QLDB.Client.update_ledger_permissions_mode)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/qldb.html#QLDB.Client.update_ledger_permissions_mode)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#update_ledger_permissions_mode)
         """
